#
# Cookbook Name:: hadoop
# Recipe:: spark_worker
#
# Copyright © 2013-2015 Cask Data, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

include_recipe 'hadoop::spark'
pkg = 'spark-worker'

if node['hadoop']['distribution'] == 'cdh'

  package pkg do
    action :nothing
  end

  # Hack to prevent auto-start of services, see COOK-26
  ruby_block "package-#{pkg}" do
    block do
      begin
        Chef::Resource::RubyBlock.send(:include, Hadoop::Helpers)
        policy_rcd('disable') if node['platform_family'] == 'debian'
        resources("package[#{pkg}]").run_action(:install)
      ensure
        policy_rcd('enable') if node['platform_family'] == 'debian'
      end
    end
  end

  service pkg do
    status_command "service #{pkg} status"
    supports [:restart => true, :reload => false, :status => true]
    action :nothing
  end
end

worker_dir =
  if node['spark'].key?('spark_env') && node['spark']['spark_env'].key?('spark_worker_dir')
    node['spark']['spark_env']['spark_worker_dir']
  else
    '/var/run/spark/work'
  end

directory worker_dir do
  mode '0755'
  owner 'spark'
  group 'spark'
  recursive true
  action :create
end
